@@ -7,4 +7,7 @@ from .quotes import Quotes
 from .intraday_tick_data import IntradayTickData
 from .ticker_last_event import TickerLastEvent
 from .corporate_events import CorporateEvents
-from .company_data import CompanyData
\ No newline at end of file
+from .company_data import CompanyData
+from .public_sources import PublicSources
+from .reference_data import ReferenceData
+from .stock_loan import StockLoan
\ No newline at end of file
